FireStoreUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDefaultFeedDocs(
dynamic appId, String path) → Stream< Map< String, dynamic> > -
getLayoutDoc(
dynamic appId) → Stream< Map< String, dynamic> > -
getPostDocs(
String appId, String path, Map< String, dynamic> query, {Map<String, dynamic> ? filters}) → Stream<List< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- firestore ↔ FirebaseFirestore
-
getter/setter pair